unfollower
====


Unfollow all your looser "friends" on twitter

Installation
------------

``pip install unfollower``


Usage
-----

usage: app.py [-h] {twitter} ...

positional arguments:
  {twitter}   [command] help
    twitter   invokes the twitter related commands

optional arguments:
  -h, --help  show this help message and exit